@@ -3,7 +3,7 @@ from typing import Dict
 from .style import Style
 
 DEFAULT_STYLES: Dict[str, Style] = {
-    "none": Style(),
+    "none": Style.null(),
     "reset": Style(
         color="default",
         bgcolor="default",
@@ -51,21 +51,25 @@ DEFAULT_STYLES: Dict[str, Style] = {
     "logging.level.warning": Style(color="red"),
     "logging.level.error": Style(color="red", bold=True),
     "logging.level.critical": Style(color="red", bold=True, reverse=True),
-    "log.level": Style(),
+    "log.level": Style.null(),
     "log.time": Style(color="cyan", dim=True),
-    "log.message": Style(),
+    "log.message": Style.null(),
     "log.path": Style(dim=True),
+    "repr.ellipsis": Style(color="yellow"),
+    "repr.indent": Style(color="green", dim=True),
     "repr.error": Style(color="red", bold=True),
     "repr.str": Style(color="green", italic=False, bold=False),
     "repr.brace": Style(bold=True),
     "repr.comma": Style(bold=True),
     "repr.ipv4": Style(bold=True, color="bright_green"),
     "repr.ipv6": Style(bold=True, color="bright_green"),
+    "repr.eui48": Style(bold=True, color="bright_green"),
+    "repr.eui64": Style(bold=True, color="bright_green"),
     "repr.tag_start": Style(bold=True),
     "repr.tag_name": Style(color="bright_magenta", bold=True),
     "repr.tag_contents": Style(color="default"),
     "repr.tag_end": Style(bold=True),
-    "repr.attrib_name": Style(color="yellow", italic=True),
+    "repr.attrib_name": Style(color="yellow", italic=False),
     "repr.attrib_equal": Style(bold=True),
     "repr.attrib_value": Style(color="magenta", italic=False),
     "repr.number": Style(color="blue", bold=True, italic=False),
@@ -75,12 +79,13 @@ DEFAULT_STYLES: Dict[str, Style] = {
     "repr.url": Style(underline=True, color="bright_blue", italic=False, bold=False),
     "repr.uuid": Style(color="bright_yellow", bold=False),
     "rule.line": Style(color="bright_green"),
-    "rule.text": Style(),
-    "prompt": Style(),
+    "rule.text": Style.null(),
+    "prompt": Style.null(),
     "prompt.choices": Style(color="magenta", bold=True),
     "prompt.default": Style(color="cyan", bold=True),
     "prompt.invalid": Style(color="red"),
     "prompt.invalid.choice": Style(color="red"),
+    "pretty": Style.null(),
     "scope.border": Style(color="blue"),
     "scope.key": Style(color="yellow", italic=True),
     "scope.key.special": Style(color="yellow", italic=True, dim=True),
@@ -89,21 +94,21 @@ DEFAULT_STYLES: Dict[str, Style] = {
     "repr.filename": Style(color="bright_magenta"),
     "table.header": Style(bold=True),
     "table.footer": Style(bold=True),
-    "table.cell": Style(),
+    "table.cell": Style.null(),
     "table.title": Style(italic=True),
     "table.caption": Style(italic=True, dim=True),
     "traceback.border.syntax_error": Style(color="bright_red"),
     "traceback.border": Style(color="red"),
-    "traceback.text": Style(),
+    "traceback.text": Style.null(),
     "traceback.title": Style(color="red", bold=True),
     "traceback.exc_type": Style(color="bright_red", bold=True),
-    "traceback.exc_value": Style(),
+    "traceback.exc_value": Style.null(),
     "traceback.offset": Style(color="bright_red", bold=True),
     "bar.back": Style(color="grey23"),
     "bar.complete": Style(color="rgb(249,38,114)"),
     "bar.finished": Style(color="rgb(114,156,31)"),
     "bar.pulse": Style(color="rgb(249,38,114)"),
-    "progress.description": Style(),
+    "progress.description": Style.null(),
     "progress.filesize": Style(color="green"),
     "progress.filesize.total": Style(color="green"),
     "progress.download": Style(color="green"),
