@@ -35,7 +35,7 @@ class RichHandler(Handler):
         tracebacks_extra_lines (int, optional): Additional lines of code to render tracebacks, or None for full width. Defaults to None.
         tracebacks_theme (str, optional): Override pygments theme used in traceback.
         tracebacks_word_wrap (bool, optional): Enable word wrapping of long tracebacks lines. Defaults to False.
-
+        tracebacks_show_locals (bool, optional): Enable display of locals in tracebacks. Defaults to False.
     """
 
     KEYWORDS: ClassVar[Optional[List[str]]] = [
@@ -66,12 +66,16 @@ class RichHandler(Handler):
         tracebacks_extra_lines: int = 3,
         tracebacks_theme: Optional[str] = None,
         tracebacks_word_wrap: bool = True,
+        tracebacks_show_locals: bool = False,
     ) -> None:
         super().__init__(level=level)
         self.console = console or get_console()
         self.highlighter = highlighter or self.HIGHLIGHTER_CLASS()
         self._log_render = LogRender(
-            show_time=show_time, show_level=show_level, show_path=show_path
+            show_time=show_time,
+            show_level=show_level,
+            show_path=show_path,
+            level_width=None,
         )
         self.enable_link_path = enable_link_path
         self.markup = markup
@@ -80,18 +84,31 @@ class RichHandler(Handler):
         self.tracebacks_extra_lines = tracebacks_extra_lines
         self.tracebacks_theme = tracebacks_theme
         self.tracebacks_word_wrap = tracebacks_word_wrap
+        self.tracebacks_show_locals = tracebacks_show_locals
+
+    def get_level_text(self, record: LogRecord) -> Text:
+        """Get the level name from the record.
+
+        Args:
+            record (LogRecord): LogRecord instance.
+
+        Returns:
+            Text: A tuple of the style and level name.
+        """
+        level_name = record.levelname
+        level_text = Text.styled(
+            level_name.ljust(8), f"logging.level.{level_name.lower()}"
+        )
+        return level_text
 
     def emit(self, record: LogRecord) -> None:
         """Invoked by logging."""
         path = Path(record.pathname).name
-        log_style = f"logging.level.{record.levelname.lower()}"
+        level = self.get_level_text(record)
         message = self.format(record)
         time_format = None if self.formatter is None else self.formatter.datefmt
         log_time = datetime.fromtimestamp(record.created)
 
-        level = Text()
-        level.append(record.levelname, log_style)
-
         traceback = None
         if (
             self.rich_tracebacks
@@ -109,6 +126,7 @@ class RichHandler(Handler):
                 extra_lines=self.tracebacks_extra_lines,
                 theme=self.tracebacks_theme,
                 word_wrap=self.tracebacks_word_wrap,
+                show_locals=self.tracebacks_show_locals,
             )
             message = record.getMessage()
 
@@ -148,7 +166,7 @@ if __name__ == "__main__":  # pragma: no cover
         level="NOTSET",
         format=FORMAT,
         datefmt="[%X]",
-        handlers=[RichHandler(rich_tracebacks=True)],
+        handlers=[RichHandler(rich_tracebacks=True, tracebacks_show_locals=True)],
     )
     log = logging.getLogger("rich")
 
@@ -179,10 +197,16 @@ if __name__ == "__main__":  # pragma: no cover
     log.info("POST /jsonrpc/ 200 65532")
     log.info("POST /admin/ 401 42234")
     log.warning("password was rejected for admin site.")
-    try:
-        1 / 0
-    except:
-        log.exception("An error of some kind occurred!")
+
+    def divide():
+        number = 1
+        divisor = 0
+        try:
+            number / divisor
+        except:
+            log.exception("An error of some kind occurred!")
+
+    divide()
     sleep(1)
     log.critical("Out of memory!")
     log.info("Server exited with code=-1")
