@@ -92,6 +92,8 @@ class Pretty:
         indent_guides (bool, optional): Enable indentation guides. Defaults to False.
         max_length (int, optional): Maximum length of containers before abbreviating, or None for no abbreviation.
             Defaults to None.
+        max_string (int, optional): Maximum length of string before truncating, or None to disable. Defaults to None.
+        expand_all (bool, optional): Expand all containers. Defaults to False.
     """
 
     def __init__(
@@ -105,6 +107,8 @@ class Pretty:
         no_wrap: Optional[bool] = False,
         indent_guides: bool = False,
         max_length: int = None,
+        max_string: int = None,
+        expand_all: bool = False,
     ) -> None:
         self._object = _object
         self.highlighter = highlighter or ReprHighlighter()
@@ -114,6 +118,8 @@ class Pretty:
         self.no_wrap = no_wrap
         self.indent_guides = indent_guides
         self.max_length = max_length
+        self.max_string = max_string
+        self.expand_all = expand_all
 
     def __rich_console__(
         self, console: "Console", options: "ConsoleOptions"
@@ -123,6 +129,8 @@ class Pretty:
             max_width=options.max_width,
             indent_size=self.indent_size,
             max_length=self.max_length,
+            max_string=self.max_string,
+            expand_all=self.expand_all,
         )
         pretty_text = Text(
             pretty_str,
@@ -310,13 +318,15 @@ class _Line:
         return f"{self.whitespace}{self.text}{self.node or ''}{self.suffix}"
 
 
-def traverse(_object: Any, max_length: int = None) -> Node:
+def traverse(_object: Any, max_length: int = None, max_string: int = None) -> Node:
     """Traverse object and generate a tree.
 
     Args:
         _object (Any): Object to be traversed.
         max_length (int, optional): Maximum length of containers before abbreviating, or None for no abbreviation.
             Defaults to None.
+        max_string (int, optional): Maximum length of string before truncating, or None to disable truncating.
+            Defaults to None.
 
     Returns:
         Node: The root of a tree structure which can be used to render a pretty repr.
@@ -324,10 +334,18 @@ def traverse(_object: Any, max_length: int = None) -> Node:
 
     def to_repr(obj: Any) -> str:
         """Get repr string for an object, but catch errors."""
-        try:
-            obj_repr = repr(obj)
-        except Exception as error:
-            obj_repr = f"<repr-error '{error}'>"
+        if (
+            max_string is not None
+            and isinstance(obj, (bytes, str))
+            and len(obj) > max_string
+        ):
+            truncated = len(obj) - max_string
+            obj_repr = f"{obj[:max_string]!r}+{truncated}"
+        else:
+            try:
+                obj_repr = repr(obj)
+            except Exception as error:
+                obj_repr = f"<repr-error '{error}'>"
         return obj_repr
 
     visited_ids: Set[int] = set()
@@ -395,8 +413,9 @@ def pretty_repr(
     *,
     max_width: int = 80,
     indent_size: int = 4,
-    expand_all: bool = False,
     max_length: int = None,
+    max_string: int = None,
+    expand_all: bool = False,
 ) -> str:
     """Prettify repr string by expanding on to new lines to fit within a given width.
 
@@ -404,9 +423,11 @@ def pretty_repr(
         _object (Any): Object to repr.
         max_width (int, optional): Desired maximum width of repr string. Defaults to 80.
         indent_size (int, optional): Number of spaces to indent. Defaults to 4.
-        expand_all (bool, optional): Expand all containers regardless of available width. Defaults to False.
         max_length (int, optional): Maximum length of containers before abbreviating, or None for no abbreviation.
             Defaults to None.
+        max_string (int, optional): Maximum length of string before truncating, or None to disable truncating.
+            Defaults to None.
+        expand_all (bool, optional): Expand all containers regardless of available width. Defaults to False.
 
     Returns:
         str: A possibly multi-line representation of the object.
@@ -415,7 +436,7 @@ def pretty_repr(
     if isinstance(_object, Node):
         node = _object
     else:
-        node = traverse(_object, max_length=max_length)
+        node = traverse(_object, max_length=max_length, max_string=max_string)
     repr_str = node.render(
         max_width=max_width, indent_size=indent_size, expand_all=expand_all
     )
@@ -426,8 +447,10 @@ def pprint(
     _object: Any,
     *,
     console: "Console" = None,
-    max_length: int = None,
     indent_guides: bool = True,
+    max_length: int = None,
+    max_string: int = None,
+    expand_all: bool = False,
 ):
     """A convenience function for pretty printing.
 
@@ -436,10 +459,22 @@ def pprint(
         console (Console, optional): Console instance, or None to use default. Defaults to None.
         max_length (int, optional): Maximum length of containers before abbreviating, or None for no abbreviation.
             Defaults to None.
+        max_string (int, optional): Maximum length of strings before truncating, or None to disable. Defaults to None.
         indent_guides (bool, optional): Enable indentation guides. Defaults to True.
+        expand_all (bool, optional): Expand all containers. Defaults to False.
     """
     _console = get_console() if console is None else console
-    _console.print(Pretty(_object, max_length=max_length, indent_guides=indent_guides))
+    _console.print(
+        Pretty(
+            _object,
+            max_length=max_length,
+            max_string=max_string,
+            indent_guides=indent_guides,
+            expand_all=expand_all,
+            overflow="ignore",
+        ),
+        soft_wrap=True,
+    )
 
 
 if __name__ == "__main__":  # pragma: no cover
@@ -470,7 +505,7 @@ if __name__ == "__main__":  # pragma: no cover
                 "pear",
                 "kumquat",
                 "kumquat",
-                "durian",
+                "durian" * 100,
             ]
         ),
         "atomic": (False, True, None),
@@ -480,4 +515,4 @@ if __name__ == "__main__":  # pragma: no cover
 
     from rich import print
 
-    print(Pretty(data, indent_guides=True))
+    print(Pretty(data, indent_guides=True, max_string=20))
