@@ -27,7 +27,7 @@ from typing import (
 )
 
 from . import filesize, get_console
-from .progress_bar import ProgressBar
+from .ansi import AnsiDecoder
 from .console import (
     Console,
     ConsoleRenderable,
@@ -40,6 +40,7 @@ from .control import Control
 from .highlighter import Highlighter
 from .jupyter import JupyterMixin
 from .live_render import LiveRender
+from .progress_bar import ProgressBar
 from .style import StyleType
 from .table import Table
 from .text import Text
@@ -480,6 +481,7 @@ class _FileProxy(io.TextIOBase):
         self.__console = console
         self.__file = file
         self.__buffer: List[str] = []
+        self.__ansi_decoder = AnsiDecoder()
 
     def __getattr__(self, name: str) -> Any:
         return getattr(self.__file, name)
@@ -498,7 +500,9 @@ class _FileProxy(io.TextIOBase):
         if lines:
             console = self.__console
             with console:
-                output = "\n".join(lines)
+                output = Text("\n").join(
+                    self.__ansi_decoder.decode_line(line) for line in lines
+                )
                 console.print(output, markup=False, emoji=False, highlight=False)
         return len(text)
 
@@ -846,8 +850,8 @@ class Progress(JupyterMixin, RenderHook):
         """Refresh (render) the progress information."""
         if self.console.is_jupyter:  # pragma: no cover
             try:
-                from ipywidgets import Output
                 from IPython.display import display
+                from ipywidgets import Output
             except ImportError:
                 import warnings
 
@@ -974,13 +978,13 @@ class Progress(JupyterMixin, RenderHook):
 
 if __name__ == "__main__":  # pragma: no coverage
 
-    import time
     import random
+    import time
 
     from .panel import Panel
+    from .rule import Rule
     from .syntax import Syntax
     from .table import Table
-    from .rule import Rule
 
     syntax = Syntax(
         '''def loop_last(values: Iterable[T]) -> Iterable[Tuple[bool, T]]:
@@ -1017,16 +1021,20 @@ if __name__ == "__main__":  # pragma: no coverage
 
     examples = cycle(progress_renderables)
 
-    console = Console()
-    with Progress(console=console, transient=True) as progress:
+    console = Console(record=True)
+    try:
+        with Progress(console=console, transient=True) as progress:
 
-        task1 = progress.add_task("[red]Downloading", total=1000)
-        task2 = progress.add_task("[green]Processing", total=1000)
-        task3 = progress.add_task("[yellow]Thinking", total=1000, start=False)
+            task1 = progress.add_task("[red]Downloading", total=1000)
+            task2 = progress.add_task("[green]Processing", total=1000)
+            task3 = progress.add_task("[yellow]Thinking", total=1000, start=False)
 
-        while not progress.finished:
-            progress.update(task1, advance=0.5)
-            progress.update(task2, advance=0.3)
-            time.sleep(0.01)
-            if random.randint(0, 100) < 1:
-                progress.log(next(examples))
+            while not progress.finished:
+                progress.update(task1, advance=0.5)
+                progress.update(task2, advance=0.3)
+                time.sleep(0.01)
+                if random.randint(0, 100) < 1:
+                    progress.log(next(examples))
+    except:
+        console.save_html("progress.html")
+        print("wrote progress.html")
