@@ -453,7 +453,11 @@ class Syntax(JupyterMixin):
         ) = self._get_number_styles(console)
 
         if self.indent_guides and not options.ascii_only:
-            style = self._get_base_style() + self._theme.get_style_for_token(Comment)
+            style = (
+                self._get_base_style()
+                + self._theme.get_style_for_token(Comment)
+                + Style(dim=True)
+            )
             text = text.with_indent_guides(self.tab_size, style=style)
 
         if not self.line_numbers:
